# AWS Demos for LPC54018 IoT Module with SEGGER Embedded Studio

This Project is based on the Amazon FreeRTOS Device Software configuration:
* LPC54018 IoT Module with IAR
* Including AWS Greengrass Discovery, MQTT, and Thing Shadow Libraries


## Hardware Requirements

* NXP - [LPC54018 IoT Module](http://www.nxp.com/LPC-AWS-Module).
* SEGGER - [J-Link Debug Probe](https://www.segger.com/products/debug-probes/j-link)
* SEGGER - [J-Link 9-Pin Cortex-M Adapter](https://www.segger.com/products/debug-probes/j-link/accessories/adapters/9-pin-cortex-m-adapter)

To debug the IoT Module with Embedded Studio, a J-Link needs to be connected to it.
The module has 10 pin 0.05" header to connect an external debug probe. Use the 9-pin Cortex-M Adapter to connect it to J-Link.


## Development Environment

This project is created for **SEGGER Embedded Studio**. [More Information](https://www.segger.com/products/development-tools/embedded-studio)

Embedded Studio is available for Window, macOS and Linux.
It can be downloaded and installed for free. [Download](https://www.segger.com/downloads/embedded-studio)

Embedded Studio can freely be used for non-commercial and non-profit educational purposes without any limitation.
Embedded Studio can freely be evaluated without technical restrictions.

This project has been created and tested with Embedded Studio V3.34.


## Project Notes

The contains the following build configuration:
* Debug RAM: Builds and links the application into the internal RAM. Can only run with a debugger, but not stand-alone.

The LPC54018 does not have internal Flash, that could be used to store and execute the application image.
Instead the device is connected to an SPI Flash.
The device can be configured to load the application image from SPI Flash into RAM, or to execute from the flash (XIP).
To create such an application, the project needs to be modified according to the NXP requirements for the LPC54018.


## Getting Started

### Prerequisites

* Follow the Amazon FreeRTOS Prerequisites instructions. (https://docs.aws.amazon.com/freertos/latest/userguide/freertos-getting-started.html)
* Connect and set up the target hardware. (see above)
* Download and install the development environment. (see above)

### Open and Build Your Project

1. Browse to *demos/nxp/lpc54018_iot_module/es*.
2. Open *aws_demos.emProject* with Embedded Studio.
3. In Embedded Studio select *Build* -> *Build Solution* and make sure the project compiles without errors and warnings.

Note: You may see one warning "NOTE: MFLASH driver expects that application runs from SRAM" from the NXP mflash driver. It can be ignored.

### Configure Your Project

#### Configure Your Wi-Fi Credentials

1. From the *Project Explorer* window, open *demos/include/aws_clientcredential.h*.
2. Specify values for the following #define constants:
    * clientcredentialWIFI_SSID: The SSID for your Wi-Fi network.
    * clientcredentialWIFI_PASSWORD: The password for your Wi-Fi network.
    * clientcredentialWIFI_SECURITY: The security type for your Wi-Fi network. Valid values are:
        * eWiFiSecurityOpen: Open, no security.
        * eWiFiSecurityWEP: WEP security.
        * eWiFiSecurityWPA: WPA security.
        * eWiFiSecurityWPA2: WPA2 security.

#### Configure Your AWS IoT Endpoint

You must specify a custom AWS IoT endpoint in order for the FreeRTOS sample code to connect to AWS IoT.

1. Browse to the AWS IoT console. (https://console.aws.amazon.com/iotv2/)
2. In the left navigation pane, choose *Settings*.
3. Copy your custom AWS IoT endpoint from the *Endpoint* text box. It should look like *<1234567890123>.iot.<us-east-1>.amazonaws.com*.
4. Open *demos/include/aws_clientcredential.h* and set *clientcredentialMQTT_BROKER_ENDPOINT* to your AWS IoT endpoint.

#### Configure Your AWS IoT Credentials

The certificate and private key must be hard-coded into the Amazon FreeRTOS code.  
Amazon FreeRTOS is a C language project, and the certificate and private key must be specially formatted to be added to the project.

1. In a browser window, open *demos/common/devmode_key_provisioning/CertificateConfigurationTool/CertificateConfigurator.html*.
2. Under *Certificate PEM file*, choose the *<ID>-certificate.pem.crt* you downloaded from the AWS IoT console.
3. Under *Private Key PEM file*, choose the *<ID>-private.pem.key* you downloaded from the AWS IoT console.
4. Select *Generate and save aws_clientcredential_keys.h* and save the file in *demos\common\include*. This overwrites the stub file that is in the directory.

### Run the FreeRTOS Samples

1. Rebuild your project with *Build* -> *Rebuild Solution*.
2. Sign in to the AWS IoT console. (https://console.aws.amazon.com/iotv2/)
3. In the left navigation pane, choose *Test* to open the MQTT client.
4. In the *Subscription topic* text box, type *freertos/demos/echo*, and then choose *Subscribe to topic*.
5. Start the debug session with *Debug* -> *Go*.
6. When the debugger stops at main(), let it run with *Debug* -> *Continue*.

In the MQTT client in AWS IoT, you should see the MQTT messages sent by your device.

[Getting Started Source](https://docs.aws.amazon.com/freertos/latest/userguide/getting_started_nxp.html)


*Created 01 Feb 2018 [JL]*